@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import codecs
 import copy
 import functools
 import io
@@ -640,7 +641,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         src, dst = self.get_action_panes(PANE_RIGHT, reverse=True)
         self.pull_all_non_conflicting_changes(src, dst)
 
-    def merge_all_non_conflicting_changes(self):
+    def merge_all_non_conflicting_changes(self, *args):
         dst = 1
         merger = merge.Merger()
         merger.differ = self.linediffer
@@ -1044,7 +1045,11 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         if os.path.exists(buf.data.savefile):
             writable = os.access(buf.data.savefile, os.W_OK)
         self.set_buffer_writable(buf, writable)
-        self.fileentry[1].set_filename(buf.data.savefile)
+
+        # FIXME: Hack around bgo#737804; remove after GTK+ 3.18 is required
+        def set_merge_file_entry():
+            self.fileentry[1].set_filename(buf.data.savefile)
+        self.scheduler.add_task(set_merge_file_entry)
         self.recompute_label()
 
     def _set_save_action_sensitivity(self):
@@ -1107,8 +1112,14 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         self._disconnect_buffer_handlers()
         self.linediffer.clear()
         self.queue_draw()
-        try_codecs = list(settings.get_value('detect-encodings'))
-        try_codecs.append('latin1')
+
+        # Build and uniquify a list of encodings to try out
+        extras = list(settings.get_value('detect-encodings'))
+        builtin = ['utf-8', GLib.get_codeset(), 'utf-16le', 'iso8859-15']
+        allencs = [codecs.lookup(c).name for c in extras + builtin]
+        seen = set()
+        try_codecs = [c for c in allencs if c not in seen and not seen.add(c)]
+
         yield _("[%s] Opening files") % self.label_text
         tasks = []
 
@@ -1141,9 +1152,24 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
                     if nextbit.find("\x00") != -1:
                         t.buf.delete(*t.buf.get_bounds())
                         filename = GObject.markup_escape_text(t.filename)
-                        add_dismissable_msg(t.pane, Gtk.STOCK_DIALOG_ERROR,
-                            _("Could not read file"),
-                            _("%s appears to be a binary file.") % filename)
+
+                        primary = _("File %s appears to be a binary file.") % filename
+                        secondary = _("Do you want to open the file using the default application?")
+                        msgarea = self.msgarea_mgr[t.pane].new_from_text_and_icon(
+                                        Gtk.STOCK_DIALOG_WARNING, primary, secondary)
+                        msgarea.add_button(_("Open"), Gtk.ResponseType.ACCEPT)
+                        msgarea.add_button(_("Hi_de"), Gtk.ResponseType.CLOSE)
+
+                        def make_binary_callback(pane, filename):
+                            def on_binary_file_open(msgarea, response_id, *args):
+                                self.msgarea_mgr[pane].clear()
+                                if response_id == Gtk.ResponseType.ACCEPT:
+                                    self._open_files([filename])
+                                return on_binary_file_open
+                            return on_binary_file_open
+
+                        msgarea.connect("response", make_binary_callback(t.pane, t.filename))
+                        msgarea.show_all()
                         tasks.remove(t)
                         continue
                 except ValueError as err:
