@@ -17,6 +17,7 @@
 import difflib
 import os
 
+from gi.repository import Gdk
 from gi.repository import Gtk
 from gi.repository import GtkSource
 
@@ -87,11 +88,16 @@ class PatchDialog(gnomeglade.Component):
         names = [self.filediff.textbuffer[i].data.label for i in range(3)]
         prefix = os.path.commonprefix(names)
         names = [n[prefix.rfind("/") + 1:] for n in names]
+        # difflib doesn't handle getting unicode file labels
+        names = [n.encode('utf8') for n in names]
 
         buf = self.textview.get_buffer()
         text0, text1 = texts[indices[0]], texts[indices[1]]
         name0, name1 = names[indices[0]], names[indices[1]]
-        diff_text = "".join(difflib.unified_diff(text0, text1, name0, name1))
+
+        diff = difflib.unified_diff(text0, text1, name0, name1)
+        unicodeify = lambda x: x.decode('utf8') if isinstance(x, str) else x
+        diff_text = "".join(unicodeify(d) for d in diff)
         buf.set_text(diff_text)
 
     def run(self):
@@ -108,8 +114,8 @@ class PatchDialog(gnomeglade.Component):
 
             # Copy patch to clipboard
             if result == 1:
-                clip = Gtk.clipboard_get()
-                clip.set_text(txt)
+                clip = Gtk.Clipboard.get_default(Gdk.Display.get_default())
+                clip.set_text(txt, -1)
                 clip.store()
                 break
             # Save patch as a file
