@@ -18,7 +18,6 @@ missing_dll = [
     'libatk-1.0-0.dll',
     'libintl-8.dll',
     'libzzz.dll',
-    'libpyglib-gi-2.0-python27-0.dll',
     'libwinpthread-1.dll',
     'libcairo-gobject-2.dll',
     'libgdk_pixbuf-2.0-0.dll',
@@ -35,20 +34,26 @@ missing_dll = [
     'libgobject-2.0-0.dll',
     'libgirepository-1.0-1.dll',
     'libgtksourceview-3.0-1.dll',
+    'libjasper-1.dll',
     'libjpeg-8.dll',
     'libpng16-16.dll',
     'libgnutls-26.dll',
-    'libxml2-2.dll',
+    'libxmlxpat.dll',
     'librsvg-2-2.dll',
     'libharfbuzz-gobject-0.dll',
-    'libwebp-4.dll',
+    'libwebp-5.dll',
 ]
 
 gtk_libs = [
+    'etc/fonts',
     'etc/gtk-3.0/settings.ini',
+    'etc/pango',
     'lib/gdk-pixbuf-2.0',
     'lib/girepository-1.0',
+    'share/fontconfig',
+    'share/fonts',
     'share/glib-2.0',
+    'share/gtksourceview-3.0',
     'share/icons',
 ]
 
